@@ -15,6 +15,7 @@ under the License.
 """
 
 import datetime as dt
+import warnings
 from collections import namedtuple
 from dataclasses import field, dataclass
 from enum import Enum
@@ -325,6 +326,7 @@ class HedgeAction(Action):
     :param transaction_cost_exit: optionally specify a different model for exits; defaults to entry cost if None
     :param risk_transformation: optional a Transformer which will be applied to the raw risk numbers before hedging
     :param holiday_calendar: optional an iterable list of holiday dates
+    :param risk_percentage: proportion of risk to hedge expressed as a percentage. Default is 100%
     """
 
     risk: RiskMeasure = field(default=None, metadata=config(decoder=decode_risk_measure,
@@ -343,34 +345,41 @@ class HedgeAction(Action):
                                                                   decoder=dc_decode(ConstantTransactionModel)))
     risk_transformation: Transformer = None
     holiday_calendar: Iterable[dt.date] = None
+    risk_percentage: float = 100
     class_type: str = static_field('hedge_action')
 
     def __post_init__(self):
         super().__post_init__()
         self._calc_type = CalcType.semi_path_dependent
-        if isinstance(self.priceables, Portfolio):
-            named_priceables = []
-            for i, priceable in enumerate(self.priceables):
-                if priceable.name is None:
-                    named_priceables.append(priceable.clone(name=f'{self.name}_Priceable{i}'))
-                elif priceable.name.startswith(self.name):
-                    named_priceables.append(priceable)
-                else:
-                    named_priceables.append(priceable.clone(name=f'{self.name}_{priceable.name}'))
-            named_priceable = Portfolio(named_priceables)
-        elif isinstance(self.priceables, Priceable):
-            if self.priceables.name is None:
-                named_priceable = self.priceables.clone(name=f'{self.name}_Priceable0')
-            elif self.priceable.name.startswith(self.name):
-                named_priceable = self.priceable
-            else:
-                named_priceable = self.priceables.clone(name=f'{self.name}_{self.priceables.name}')
-        else:
+        portfolio = (
+            self.priceables
+            if isinstance(self.priceables, Portfolio)
+            else Portfolio(self.priceables.clone(name=None), name=self.priceables.name)
+            if isinstance(self.priceables, Priceable)
+            else None
+        )
+
+        if not Portfolio:
             raise RuntimeError('hedge action only accepts one trade or one portfolio')
+
+        named_priceables = []
+        for i, priceable in enumerate(portfolio):
+            if priceable.name is None:
+                named_priceables.append(priceable.clone(name=f'{self.name}_Priceable{i}'))
+            elif priceable.name.startswith(self.name):
+                named_priceables.append(priceable)
+            else:
+                named_priceables.append(priceable.clone(name=f'{self.name}_{priceable.name}'))
+        named_priceable = Portfolio(named_priceables, name=portfolio.name)
+
         self.priceables = named_priceable
         if self.transaction_cost_exit is None:
             self.transaction_cost_exit = self.transaction_cost
 
+        if self.scaling_parameter != 'notional_amount':
+            warnings.warn('HedgeAction.scaling_parameter is deprecated. It is no longer used and will be removed '
+                          'in a future release', DeprecationWarning, stacklevel=2)
+
     @property
     def priceable(self):
         return self.priceables
