@@ -328,6 +328,13 @@ class Security(XRef, Instrument):
         Instrument.__init__(self)
         self.quantity_ = quantity
 
+    @classmethod
+    def from_dict(cls, env):
+        return cls(**{
+            k: v for k, v in env.items()
+            if k in inspect.signature(cls).parameters
+        })
+
 
 def encode_instrument(instrument: Optional[Instrument]) -> Optional[dict]:
     if instrument is not None:
